@@ -1,6 +1,6 @@
 package Test::SSH;
 
-our $VERSION = '0.04';
+our $VERSION = '0.07';
 
 use strict;
 use warnings;
@@ -15,9 +15,17 @@ my (@extra_path, @default_user_keys, $default_user, $private_dir);
 my @default_test_commands = ('true', 'exit', 'echo foo', 'date',
                              'cmd /c ver', 'cmd /c echo foo');
 
-if ( $^O =~ /^Win/) {
+if ( $^O =~ /^MSWin/) {
     require Win32;
     $default_user = Win32::LoginName();
+	
+	my @pf;
+	for my $folder (qw(PROGRAM_FILES PROGRAM_FILES_COMMON)) {
+		my $dir = eval "Win32::GetFolderPath(Win32::$folder)";
+		if (defined $dir) {
+		    push @extra_path, File::Spec->join($dir, 'PuTTY');
+		}
+	}
 }
 else {
     @extra_path = ( map { File::Spec->join($_, 'bin'), File::Spec->join($_, 'sbin') }
@@ -222,6 +230,13 @@ For instance:
 
   my $sshd = Test::SSH->new(run_server => ($ENV{AUTHOR_TESTING} || $ENV{AUTOMATED_TESTING}));
 
+=item override_server_config => $hash_reference
+
+Key/Value pairs in this hash reference will be used to override the
+defaults for the C<sshd_config> file of the C<sshd> server started. If
+a value in this hash is undef, the respective key of the server config
+will be deleted.
+
 =back
 
 Also, the following environment variables can be used to change the
@@ -332,7 +347,8 @@ Amazon Wish List: L<http://amzn.com/w/1WU1P6IR5QZ42>.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2013 by Salvador FandiE<ntilde>o (sfandino@yahoo.com)
+Copyright (C) 2013,2016 by Salvador FandiE<ntilde>o (sfandino@yahoo.com),
+    Andreas KE<ouml>nig (andk@cpan.org)
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.14.2 or,
