@@ -10,6 +10,7 @@ our @ISA = qw(Test::SSH::Backend::Base);
 
 sub new {
     my ($class, %opts) = @_;
+    my $override_server_config = delete $opts{override_server_config} || {};
     my $sshd = $class->SUPER::new(%opts, auth_method => 'publickey');
     unless ($sshd->{run_server}) {
         $sshd->_log("backend skipped because run_server is set to false");
@@ -20,8 +21,10 @@ sub new {
     $sshd->_create_keys or return;
     my $run_dir = $sshd->_run_dir;
     my $port = $sshd->{port} = $sshd->_find_unused_port;
+    use Tie::IxHash; # order must be preserved because Port must come before ListenAddress
 
-    $sshd->_write_config(HostKey            => $sshd->{host_key_path},
+    tie my %Config, 'Tie::IxHash',
+        (                HostKey            => $sshd->{host_key_path},
                          AuthorizedKeysFile => $sshd->_user_key_path_quoted . ".pub",
                          AllowUsers         => $sshd->{user}, # only user running the script can log
                          AllowTcpForwarding => 'yes',
@@ -35,7 +38,18 @@ sub new {
                          PidFile            => "$run_dir/sshd.pid",
                          PrintLastLog       => 'no',
                          PrintMotd          => 'no',
-                         UseDNS             => 'no')
+                         Subsystem          => 'sftp /usr/lib/openssh/sftp-server',
+                         UseDNS             => 'no',
+                         UsePrivilegeSeparation => 'no',
+        );
+    while (my($k,$v) = each %$override_server_config) {
+        if (defined $v) {
+            $Config{$k} = $v;
+        } else {
+            delete $Config{$k};
+        }
+    }
+    $sshd->_write_config(%Config)
         or return;
 
     $sshd->_log('starting SSH server');
@@ -121,7 +135,7 @@ sub _create_key {
     $sshd->_log("generating key '$fn'");
     my $tmpfn = join('.', $fn, $$, int(rand(9999999)));
     if ($sshd->_run_cmd( { search_binary => 1 },
-                         'ssh_keygen', -t => 'dsa', -b => 1024, -f => $tmpfn, -P => '')) {
+                         'ssh_keygen', -t => 'rsa', -b => 1024, -f => $tmpfn, -P => '')) {
         unlink $fn;
         unlink "$fn.pub";
         if (rename $tmpfn, $fn and
